##  Step 3: Define Fact Sheet Type
Configure which fact sheet type to synchronize:
  * If SAP LeanIX is the source system: Select Application or an application subtype. The selected fact sheet type is pushed to Jira Service Management.
  * If Jira Service Management is the source system: Select IT Component or an IT component subtype. The selected fact sheet type is the target in SAP LeanIX.


Choose Next after selecting the fact sheet type.
